.. _spkg_gnumake_tokenpool:

gnumake_tokenpool: Jobclient and jobserver for the GNU make tokenpool protocol
========================================================================================

Description
-----------

The project has implementations in multiple languages.

We only install the implementation in Python.


License
-------

MIT


Upstream Contact
----------------

- https://github.com/milahu/gnumake-tokenpool (upstream)

Type
----

standard


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)

Version Information
-------------------

package-version.txt::

    0.0.7

version_requirements.txt::

    gnumake-tokenpool >= 0.0.4


Equivalent System Packages
--------------------------

(none known)

